Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(303)

Unified Diff: third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp

Issue 1858163002: Rename inDocument() to inShadowIncludingDocument() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Node.cpp ('k') | third_party/WebKit/Source/core/dom/Range.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp
diff --git a/third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp b/third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp
index c7519c83bb3178bd6e14ec21a26b33deb761280b..86abb2ddbd9a4cb1a68cd243de3f498b5fee2959 100644
--- a/third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp
+++ b/third_party/WebKit/Source/core/dom/ProcessingInstruction.cpp
@@ -60,9 +60,9 @@ ProcessingInstruction::~ProcessingInstruction()
clearSheet();
// FIXME: ProcessingInstruction should not be in document here.
// However, if we add ASSERT(!inDocument()), fast/xsl/xslt-entity.xml
// crashes. We need to investigate ProcessingInstruction lifetime.
- if (inDocument() && m_isCSS)
+ if (inShadowIncludingDocument() && m_isCSS)
document().styleEngine().removeStyleSheetCandidateNode(this);
clearEventListenerForXSLT();
#endif
@@ -203,7 +203,7 @@ bool ProcessingInstruction::sheetLoaded()
void ProcessingInstruction::setCSSStyleSheet(const String& href, const KURL& baseURL, const String& charset, const CSSStyleSheetResource* sheet)
{
- if (!inDocument()) {
+ if (!inShadowIncludingDocument()) {
ASSERT(!m_sheet);
return;
}
@@ -228,7 +228,7 @@ void ProcessingInstruction::setCSSStyleSheet(const String& href, const KURL& bas
void ProcessingInstruction::setXSLStyleSheet(const String& href, const KURL& baseURL, const String& sheet)
{
- if (!inDocument()) {
+ if (!inShadowIncludingDocument()) {
ASSERT(!m_sheet);
return;
}
@@ -259,7 +259,7 @@ void ProcessingInstruction::parseStyleSheet(const String& sheet)
Node::InsertionNotificationRequest ProcessingInstruction::insertedInto(ContainerNode* insertionPoint)
{
CharacterData::insertedInto(insertionPoint);
- if (!insertionPoint->inDocument())
+ if (!insertionPoint->inShadowIncludingDocument())
return InsertionDone;
String href;
@@ -275,7 +275,7 @@ Node::InsertionNotificationRequest ProcessingInstruction::insertedInto(Container
void ProcessingInstruction::removedFrom(ContainerNode* insertionPoint)
{
CharacterData::removedFrom(insertionPoint);
- if (!insertionPoint->inDocument())
+ if (!insertionPoint->inShadowIncludingDocument())
return;
// No need to remove XSLStyleSheet from StyleEngine.
« no previous file with comments | « third_party/WebKit/Source/core/dom/Node.cpp ('k') | third_party/WebKit/Source/core/dom/Range.h » ('j') | no next file with comments »
@@ -60,9 +60,9 @@ ProcessingInstruction::~ProcessingInstruction()
clearSheet();
// FIXME: ProcessingInstruction should not be in document here.
- // However, if we add ASSERT(!inDocument()), fast/xsl/xslt-entity.xml
+ // However, if we add ASSERT(!inShadowIncludingDocument()), fast/xsl/xslt-entity.xml
// crashes. We need to investigate ProcessingInstruction lifetime.

Powered by Google App Engine
This is Rietveld 408576698